@@ -7,23 +7,23 @@ from botocore.credentials import RefreshableCredentials
 from boto3 import Session
 from botocore.session import get_session
 
+from spackle.exceptions import SpackleException
+
 
 class DynamoDB:
-    client = None
-    identity_id = None
-    table_name = None
-    aws_region = None
-    role_arn = None
-    token = None
+    adapter_config = None
 
     def __init__(self):
         self.client = self._bootstrap_client()
 
     def get_item(self, key):
+        if not self.adapter_config:
+            raise SpackleException("Adapter not configured")
+
         return self.client.get_item(
-            TableName=self.table_name,
+            TableName=self.adapter_config["table_name"],
             Key={
-                "AccountId": {"S": self.identity_id},
+                "AccountId": {"S": self.adapter_config["identity_id"]},
                 **key,
             },
         )
@@ -32,36 +32,45 @@ class DynamoDB:
         log.log_debug("Bootstrapping DynamoDB client...")
 
         session_credentials = RefreshableCredentials.create_from_metadata(
-            metadata=self._refresh(),
-            refresh_using=self._refresh,
+            metadata=self._refresh_credentials(),
+            refresh_using=self._refresh_credentials,
             method="sts-assume-role-with-web-identity",
         )
         session = get_session()
         session._credentials = session_credentials
         autorefresh_session = Session(botocore_session=session)
-        return autorefresh_session.client("dynamodb", region_name=self.aws_region)
+        return autorefresh_session.client(
+            "dynamodb", region_name=self.adapter_config["region"]
+        )
 
-    def _refresh(self):
+    def _refresh_credentials(self):
+        log.log_debug("Refreshing credentials...")
+        self._configure()
+        return self._fetch_credentials()
+
+    def _configure(self):
         from spackle import api_key, api_base
 
-        log.log_debug("Refreshing credentials...")
         session = requests.post(
-            f"{api_base}/auth/session",
+            f"{api_base}/sessions",
             headers={"Authorization": f"Bearer {api_key}"},
         ).json()
-        self.identity_id = session["identity_id"]
-        self.table_name = session["table_name"]
-        self.token = session["token"]
-        self.role_arn = session["role_arn"]
-        self.aws_region = session["aws_region"]
-        log.log_debug("Created session: %s" % session)
 
-        log.log_debug("Assuming aws role %s..." % self.role_arn)
+        self.adapter_config = session["adapter"]
+        log.log_debug("Configured adapter: %s" % session)
+
+        return session
+
+    def _fetch_credentials(self):
+        if not self.adapter_config:
+            raise SpackleException("Adapter not configured")
+
+        log.log_debug("Assuming aws role %s..." % self.adapter_config["role_arn"])
         sts_client = boto3.client("sts")
         response = sts_client.assume_role_with_web_identity(
-            RoleArn=self.role_arn,
+            RoleArn=self.adapter_config["role_arn"],
             RoleSessionName=str(uuid.uuid4()),
-            WebIdentityToken=self.token,
+            WebIdentityToken=self.adapter_config["token"],
         )
 
         return {
